﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'zh', {
	acccessKey: '便捷鍵',
	advanced: '進階',
	advisoryContentType: '建議內容類型',
	advisoryTitle: '標題',
	anchor: {
		toolbar: '錨點',
		menu: '編輯錨點',
		title: '錨點內容',
		name: '錨點名稱',
		errorName: '請輸入錨點名稱',
		errorWhitespace: '錨定名稱不能包含空格字元',
		remove: '移除錨點'
	},
	anchorId: '依元件編號',
	anchorName: '依錨點名稱',
	charset: '連結資源的字元集',
	cssClasses: '樣式表類別',
	download: '強制下載',
	displayText: '顯示文字',
	emailAddress: '電子郵件地址',
	emailBody: '郵件本文',
	emailSubject: '郵件主旨',
	id: 'ID',
	info: '連結資訊',
	langCode: '語言碼',
	langDir: '語言方向',
	langDirLTR: '由左至右 (LTR)',
	langDirRTL: '由右至左 (RTL)',
	menu: '編輯連結',
	name: '名稱',
	noAnchors: '(本文件中無可用之錨點)',
	noEmail: '請輸入電子郵件',
	noUrl: '請輸入連結 URL',
	noTel: '請輸入電話號碼',
	other: '<其他>',
	phoneNumber: '電話號碼',
	popupDependent: '獨立 (Netscape)',
	popupFeatures: '快顯視窗功能',
	popupFullScreen: '全螢幕 (IE)',
	popupLeft: '左側位置',
	popupLocationBar: '位置列',
	popupMenuBar: '功能表列',
	popupResizable: '可調大小',
	popupScrollBars: '捲軸',
	popupStatusBar: '狀態列',
	popupToolbar: '工具列',
	popupTop: '頂端位置',
	rel: '關係',
	selectAnchor: '選取一個錨點',
	styles: '樣式',
	tabIndex: '定位順序',
	target: '目標',
	targetFrame: '<框架>',
	targetFrameName: '目標框架名稱',
	targetPopup: '<快顯視窗>',
	targetPopupName: '快顯視窗名稱',
	title: '連結',
	toAnchor: '文字中的錨點連結',
	toEmail: '電子郵件',
	toUrl: '網址',
	toPhone: '電話',
	toolbar: '連結',
	type: '連結類型',
	unlink: '取消連結',
	upload: '上傳'
} );
